@@ -19,6 +19,7 @@ type JobListCommand struct {
 	*baseCommand
 
 	flagJson               bool
+	flagVerbose            bool
 	flagLimit              int
 	flagDesc               bool
 	flagState              []string
@@ -209,7 +210,10 @@ func (c *JobListCommand) Run(args []string) int {
 
 	c.ui.Output("Waypoint Jobs", terminal.WithHeaderStyle())
 
-	tblHeaders := []string{"ID", "Operation", "State", "Time Completed", "Target Runner", "Workspace", "Project", "Application", "Pipeline"}
+	tblHeaders := []string{"ID", "Operation", "State", "Time Queued", "Time Completed", "Target Runner", "Project", "Workspace"}
+	if c.flagVerbose {
+		tblHeaders = append(tblHeaders, []string{"Application", "Pipeline"}...)
+	}
 	tbl := terminal.NewTable(tblHeaders...)
 
 	for _, j := range jobs {
@@ -289,6 +293,11 @@ func (c *JobListCommand) Run(args []string) int {
 			targetRunner = target.Id.Id
 		}
 
+		var queueTime string
+		if j.QueueTime != nil {
+			queueTime = humanize.Time(j.QueueTime.AsTime())
+		}
+
 		var completeTime string
 		if j.CompleteTime != nil {
 			completeTime = humanize.Time(j.CompleteTime.AsTime())
@@ -303,12 +312,18 @@ func (c *JobListCommand) Run(args []string) int {
 			j.Id,
 			op,
 			jobState,
+			queueTime,
 			completeTime,
 			targetRunner,
-			j.Workspace.Workspace,
 			j.Application.Project,
-			j.Application.Application,
-			pipeline,
+			j.Workspace.Workspace,
+		}
+
+		if c.flagVerbose {
+			tblColumn = append(tblColumn, []string{
+				j.Application.Application,
+				pipeline,
+			}...)
 		}
 
 		tbl.Rich(tblColumn, nil)
@@ -374,7 +389,14 @@ func (c *JobListCommand) Flags() *flag.Sets {
 			Name:    "json",
 			Target:  &c.flagJson,
 			Default: false,
-			Usage:   "Output the list of jobs as json.",
+			Usage:   "Output the list of jobs as json. Includes all fields for jobs.",
+		})
+
+		f.BoolVar(&flag.BoolVar{
+			Name:    "verbose",
+			Target:  &c.flagVerbose,
+			Default: false,
+			Usage:   "Output more details for a job.",
 		})
 
 		f.IntVar(&flag.IntVar{
