@@ -217,6 +217,11 @@ func Commands(
 				baseCommand: baseCommand,
 			}, nil
 		},
+		"config delete": func() (cli.Command, error) {
+			return &ConfigDeleteCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
 		"config source-get": func() (cli.Command, error) {
 			return &ConfigSourceGetCommand{
 				baseCommand: baseCommand,
@@ -227,6 +232,11 @@ func Commands(
 				baseCommand: baseCommand,
 			}, nil
 		},
+		"config source-delete": func() (cli.Command, error) {
+			return &ConfigSourceDeleteCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
 		"config sync": func() (cli.Command, error) {
 			return &ConfigSyncCommand{
 				baseCommand: baseCommand,
