@@ -6,13 +6,14 @@ import (
 	"time"
 
 	"github.com/hashicorp/go-hclog"
-	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
-	"github.com/hashicorp/waypoint/internal/clierrors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/apimachinery/pkg/watch"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/tools/clientcmd"
+
+	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
+	"github.com/hashicorp/waypoint/internal/clierrors"
 )
 
 type K8sConfig struct {
@@ -23,7 +24,7 @@ type K8sConfig struct {
 	RunnerImage          string `hcl:"runner_image,optional"`
 	CpuRequest           string `hcl:"runner_cpu_request,optional"`
 	MemRequest           string `hcl:"runner_mem_request,optional"`
-	CreateServiceAccount bool   `hcl:"odr_service_account_init,optional"`
+	CreateServiceAccount bool   `hcl:"create_service_account,optional"`
 	OdrImage             string `hcl:"odr_image"`
 
 	// Required for backwards compatibility
