@@ -84,6 +84,7 @@ const odrRolePolicy = `{
         "ecs:DeregisterTaskDefinition",
         "ecs:RunTask",
         "ecs:StopTask",
+        "elasticloadbalancing:AddTags",
         "elasticloadbalancing:CreateListener",
         "elasticloadbalancing:CreateLoadBalancer",
         "elasticloadbalancing:CreateRule",
@@ -95,9 +96,10 @@ const odrRolePolicy = `{
         "elasticloadbalancing:DescribeListeners",
         "elasticloadbalancing:DescribeLoadBalancers",
         "elasticloadbalancing:DescribeRules",
+		"elasticloadbalancing:DescribeTags,
         "elasticloadbalancing:DescribeTargetGroups",
         "elasticloadbalancing:ModifyListener",
-	"elasticloadbalancing:DescribeTargetHealth",
+		"elasticloadbalancing:DescribeTargetHealth",
         "iam:AttachRolePolicy",
         "iam:CreateRole",
         "iam:GetRole",
@@ -397,7 +399,7 @@ func (i *ECSRunnerInstaller) Uninstall(ctx context.Context, opts *InstallOpts) e
 		}
 	}
 
-	if *fileSystemId == "" {
+	if fileSystemId == nil || *fileSystemId == "" {
 		s.Update("File system with tag key `runner-id` and value " + opts.Id + " not detected, skipping deletion")
 		s.Done()
 		return nil
